@@ -3,12 +3,13 @@
   -------------------
   Calculations for brewing model
   -------------------
-  Copyright (c) 2004 David Johnson
+  Copyright (c) 2004-2005 David Johnson
   Please see the header file for copyright and license information.
 ***************************************************************************/
 
 #include <math.h>
 
+#include "resource.h"
 #include "calc.h"
 #include "recipe.h"
 
@@ -19,6 +20,10 @@ double Calc::efficiency_ = 0.75;
 bool Calc::tinseth_ = true;
 bool Calc::morey_ = true;
 
+#ifndef HAVE_ROUND
+#define round(x) floor(x+0.5)
+#endif
+
 //////////////////////////////////////////////////////////////////////////////
 // recalc()
 // --------
@@ -70,7 +75,7 @@ double Calc::calcOG(Recipe *r)
 // ---------
 // Calculate the bitterness
 
-double Calc::calcIBU(Recipe *r)
+int Calc::calcIBU(Recipe *r)
 {
     // switch between two possible calculations
     if (tinseth_)
@@ -84,9 +89,9 @@ double Calc::calcIBU(Recipe *r)
 // --------------
 // Calculate the bitterness based on Rager's method (table method)
 
-double Calc::calcRagerIBU(Recipe *r)
+int Calc::calcRagerIBU(Recipe *r)
 {
-    HopsList *list = r->hops();
+    HopList *list = r->hops();
     double bitterness = 0.0;
     HopIterator it;
     for (it=list->begin(); it!=list->end(); ++it) {
@@ -96,7 +101,7 @@ double Calc::calcRagerIBU(Recipe *r)
     bitterness /= r->size().amount(Volume::gallon);
     // correct for boil gravity
     if (r->og_ > 1.050) bitterness /= 1.0 + ((r->og_ - 1.050) / 0.2);
-    return bitterness;
+    return (int)round(bitterness);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -108,9 +113,9 @@ double Calc::calcRagerIBU(Recipe *r)
 // ---------------------------------------------------------------
 // (volume*4.15)
 
-// TODO: check and recheck this formula
+// TODO: recheck this formula
 
-double Calc::calcTinsethIBU(Recipe *r)
+int Calc::calcTinsethIBU(Recipe *r)
 {
     const double GPO = 28.3495; // grams per ounce
     const double LPG = 3.785;   // liters per gallon
@@ -120,7 +125,7 @@ double Calc::calcTinsethIBU(Recipe *r)
     const double COEFF3 = 0.04;
     const double COEFF4 = 4.15;
 
-    HopsList *list = r->hops();
+    HopList *list = r->hops();
     double bitterness = 0.0;
     HopIterator it;
     for (it=list->begin(); it!=list->end(); ++it) {
@@ -131,7 +136,7 @@ double Calc::calcTinsethIBU(Recipe *r)
         bitterness += ibu;
     }
     bitterness *= (GPO / LPG) / 100.0;
-    return bitterness;
+    return (int)round(bitterness);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -153,7 +158,7 @@ double Calc::utilization(unsigned time)
 // ---------
 // Calculate the color
 
-double Calc::calcSRM(Recipe *r)
+int Calc::calcSRM(Recipe *r)
 {
     GrainList *list = r->grains();
     double srm = 0.0;
@@ -175,7 +180,7 @@ double Calc::calcSRM(Recipe *r)
             srm += 8.4;
         }
     }
-    return srm;
+    return (int)round(srm);
 }
 
 // TODO: following formulas need to use constants
@@ -200,6 +205,27 @@ double Calc::SgToP(double sg) {
     return ((-463.37) + (668.72*sg) - (205.35 * sg * sg));
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// extractToYield()
+// ----------------
+// Convert extract potential to percent yield
+
+// TODO: need to double check this, as well as terms
+double Calc::extractToYield(double extract) {
+    const double SUCROSE = 46.21415;
+    return (((extract-1.0)*1000.0) / SUCROSE);
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// yieldToExtract()
+// ----------------
+// Convert percent yield to extract potential
+
+double Calc::yieldToExtract(double yield) {
+    const double SUCROSE = 46.21415;
+    return ((yield*SUCROSE)/1000.0)+1.0;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // ABV()
 // -----
