@@ -3,7 +3,7 @@
   -------------------
   Calculations for brewing model
   -------------------
-  Copyright (c) 2001-2004 David Johnson
+  Copyright (c) 2001-2005 David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,6 @@ const QString attrGenerator         = "generator";
 const QString tagTitle              = "title";
 const QString tagBrewer             = "brewer";
 const QString tagBatch              = "batch";
-const QString attrSize              = "size"; // TODO: deprecated tag (2.1 prev)
 const QString attrMash              = "mash";
 const QString tagNotes              = "notes";
 const QString attrClass             = "class";
@@ -68,6 +67,8 @@ const QString tagStyles             = "styles";
 const QString tagStyle              = "style";
 const QString attrOGLow             = "oglow";
 const QString attrOGHigh            = "oghigh";
+const QString attrFGLow             = "fglow";
+const QString attrFGHigh            = "fghigh";
 const QString attrIBULow            = "ibulow";
 const QString attrIBUHigh           = "ibuhigh";
 const QString attrSRMLow            = "srmlow";
@@ -90,6 +91,52 @@ const QString tagUtilization        = "utilization";
 const QString tagEntry              = "entry";
 const QString attrUtil              = "util";
 
+// BeerXML Format Strings
+
+// TODO: see if I can use lowercase, converting on the fly during import/export
+const QString beerXMLVersion        = "1";
+const QString tagRECIPES            = "RECIPES";
+const QString tagRECIPE             = "RECIPE";
+const QString tagNAME               = "NAME";
+const QString tagVERSION            = "VERSION";
+const QString tagTYPE               = "TYPE";
+const QString tagSTYLE              = "STYLE";
+const QString tagBREWER             = "BREWER";
+const QString tagBATCHSIZE          = "BATCH_SIZE";
+const QString tagEFFICIENCY         = "EFFICIENCY";
+const QString tagFERMENTABLES       = "FERMENTABLES";
+const QString tagFERMENTABLE        = "FERMENTABLE";
+const QString tagHOPS               = "HOPS";
+const QString tagHOP                = "HOP";
+const QString tagYEASTS             = "YEASTS";
+const QString tagYEAST              = "YEAST";
+const QString tagMISCS              = "MISCS";
+const QString tagMISC               = "MISC";
+const QString tagNOTES              = "NOTES";
+const QString tagWATERS             = "WATERS";
+
+const QString tagOGMIN              = "OG_MIN";
+const QString tagOGMAX              = "OG_MAX";
+const QString tagFGMIN              = "FG_MIN";
+const QString tagFGMAX              = "FG_MAX";
+const QString tagIBUMIN             = "IBU_MIN";
+const QString tagIBUMAX             = "IBU_MAX";
+const QString tagCOLORMIN           = "COLOR_MIN";
+const QString tagCOLORMAX           = "COLOR_MAX";
+
+const QString tagAMOUNT             = "AMOUNT";
+const QString tagYIELD              = "YIELD";
+const QString tagCOLOR              = "COLOR";
+
+const QString tagALPHA              = "ALPHA";
+const QString tagUSE                = "USE";
+const QString tagTIME               = "TIME";
+const QString tagFORM               = "FORM";
+
+const QString TYPE_EXTRACT          = "Extract";
+const QString TYPE_PARTIAL          = "Partial Mash";
+const QString TYPE_ALLGRAIN         = "All Grain";
+
 } // CalcResource
  
 // utilization table entry structure
@@ -106,6 +153,7 @@ class Calc {
 
     // set efficiency
     static void setEfficiency(double e);
+    static double efficiency();
     // set ibu calc method
     static void setTinseth(bool tinseth);
     // set srm calc method
@@ -122,12 +170,15 @@ class Calc {
     static double ABW(Recipe *r);
     static double ABW(double og, double fg);
     // return bitterness
-    static double IBU(Recipe *r);
+    static int IBU(Recipe *r);
     // return color
-    static double SRM(Recipe *r);
+    static int SRM(Recipe *r);
 
     // convert Specific Gravity to Plato
     static double Calc::SgToP(double sg);
+    // convert grain extract to yield
+    static double Calc::extractToYield(double extract);
+    static double Calc::yieldToExtract(double yield);
 
     // add an entry to the utilization table
     static void addUEntry(const UEntry &u);
@@ -136,10 +187,10 @@ class Calc {
 
  private:
     static double calcOG(Recipe *r);
-    static double calcSRM(Recipe *r);
-    static double calcIBU(Recipe *r);
-    static double calcRagerIBU(Recipe *r);
-    static double calcTinsethIBU(Recipe *r);
+    static int calcSRM(Recipe *r);
+    static int calcIBU(Recipe *r);
+    static int calcRagerIBU(Recipe *r);
+    static int calcTinsethIBU(Recipe *r);
     static double utilization(unsigned time);
 
  private:
@@ -153,15 +204,17 @@ class Calc {
 
 inline void Calc::setEfficiency(double e) { efficiency_ = e; }
 
+inline double Calc::efficiency() { return efficiency_; }
+
 inline void Calc::setTinseth(bool tinseth) { tinseth_ = tinseth; }
 
 inline void Calc::setMorey(bool morey) { morey_ = morey; }
 
 inline double Calc::OG(Recipe *r) { return r->og_; }
 
-inline double Calc::IBU(Recipe *r) { return r->ibu_; }
+inline int Calc::IBU(Recipe *r) { return r->ibu_; }
 
-inline double Calc::SRM(Recipe *r) { return r->srm_; }
+inline int Calc::SRM(Recipe *r) { return r->srm_; }
 
 inline const QValueList<UEntry> &Calc::getUEntryList() { return utable_; }
 
