@@ -3,7 +3,7 @@
   -------------------
   Control class for QBrew
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,8 @@
 #ifndef CONTROLLER_H
 #define CONTROLLER_H
 
+#include <qaction.h>
+#include <qdict.h>
 #include <qguardedptr.h>
 #include <qmainwindow.h>
 
@@ -43,6 +45,7 @@ class QAction;
 class QCloseEvent;
 class QImage;
 class QPopupMenu;
+class QPrinter;
 class QTimer;
 class QToolBar;
 
@@ -50,6 +53,7 @@ class AlcoholTool;
 class Configure;
 class HelpWindow;
 class HydrometerTool;
+class DatabaseTool;
 class Model;
 class View;
 
@@ -66,9 +70,6 @@ public:
     // Initialize the controller
     void initialize(const QString &filename = "");
 
-    // return recipe as an ascii string
-    QString getRecipeText(); // TODO: put in model?
-    
     // return out the base dir for the help documents
     QString docBase();
     // return out the base dir for the data files
@@ -76,6 +77,8 @@ public:
 
     // return image from embedded image data (qembed)
     static const QImage& findImage(const QString& name);
+    // return current application state
+    const ConfigState& state();
 
 public slots:
     // generate a new document
@@ -88,22 +91,24 @@ public slots:
     void fileSave();
     // save a document under a different filename
     void fileSaveAs();
+    // export the document to non-native format
+    void fileExport();
     // print the document
     void filePrint();
-    
+
+    // Popup the alcohol calculator tool
+    void toolsAlcohol();
+    // Popup the hydrometer correction tool
+    void toolsHydrometer();
+    // Bring up the database editor
+    void toolsDatabase();
+
     // toggle the toolbar
     void optionsToolbar();
     // toggle the statusbar
     void optionsStatusbar();
     // display the configuration dialog
     void optionsConfigure();
-    // save application settings
-    void optionsSaveConfigure();
-
-    // Popup the alcohol calculator tool
-    void toolsAlcohol();
-    // Popup the hydrometer correction tool
-    void toolsHydrometer();
 
     // displays help contents
     void helpContents();
@@ -166,9 +171,10 @@ private slots:
     void applyGeneralState(const GenConfigState &state);
     void applyRecipeState(const RecipeConfigState &state);
     void applyCalcState(const CalcConfigState &state);
+    void saveConfig();
 
     // autosave time
-    void autoSave(); 
+    void autoSave();
 
 private:
     friend class nofriendsatall; // to avoid warnings
@@ -183,37 +189,23 @@ private:
     QGuardedPtr<HelpWindow> primerwin_;
     QGuardedPtr<AlcoholTool> alcoholtool_;
     QGuardedPtr<HydrometerTool> hydrometertool_;
+    QGuardedPtr<DatabaseTool> databasetool_;
     QString filename_;
     bool newflag_;
 
-    // TODO: replace with a QDict, like in pyxis
-    QAction *filenew_;
-    QAction *fileopen_;
-    QAction *filesave_;
-    QAction *filesaveas_;
-    QAction *fileprint_;
-    QAction *filequit_;
-    QAction *optionstoolbar_;
-    QAction *optionsstatusbar_;
-    QAction *optionssetup_;
-    QAction *optionssavesetup_;
-    QAction *toolhydrometer_;
-    QAction *toolalcohol_;
-    QAction *helpcontents_;
-    QAction *helpprimer_;
-    QAction *helpabout_;
-    QAction *helpcontext_;
+    QDict<QAction> actions_;
 
+    QPopupMenu* filerecentmenu_;
     QPopupMenu* filemenu_;
-    QPopupMenu* optionsmenu_;
     QPopupMenu* toolsmenu_;
+    QPopupMenu* optionsmenu_;
     QPopupMenu* helpmenu_;
     QToolBar* toolbar_;
 
     QStringList recent_;
-    QPopupMenu* recentmenu_;
 
     QTimer *autosave_;
+    QPrinter *printer_;
     bool backed_;
 };
 
