@@ -3,11 +3,10 @@
   -------------------
   A grain class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include <cmath>
 #include <qregexp.h>
 #include <qstring.h>
 #include <qstringlist.h>
@@ -16,7 +15,7 @@
 #include "grain.h"
 
 //////////////////////////////////////////////////////////////////////////////
-// Construction, destruction                                                //
+// Grain Class                                                              //
 //////////////////////////////////////////////////////////////////////////////
 
 //////////////////////////////////////////////////////////////////////////////
@@ -50,10 +49,6 @@ Grain::Grain(const Grain &g)
       color_(g.color_), use_(g.use_), yield_(g.yield_), hcu_(g.hcu_)
 { ; }
 
-//////////////////////////////////////////////////////////////////////////////
-// Operators                                                                //
-//////////////////////////////////////////////////////////////////////////////
-
 //////////////////////////////////////////////////////////////////////////////
 // operator=()
 // -----------
@@ -87,16 +82,12 @@ bool Grain::operator==(const Grain &g)
         && (use_ == g.use_);
 }
 
-///////////////////////////////////////////////////////////////////////////////
-// Miscellaneous                                                             //
-///////////////////////////////////////////////////////////////////////////////
-
 ///////////////////////////////////////////////////////////////////////////////
 // useString()
 // -----------
 // Return usage as a string
 
-QString Grain::useString()
+QString Grain::useString() const
 {
     switch (use_) {
         case GRAIN_EXTRACT: return "extract";
@@ -136,33 +127,32 @@ int Grain::useStringToEnum(const QString &name)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// GrainListItem class                                                      //
+// GrainItem class                                                          //
 //////////////////////////////////////////////////////////////////////////////
 
-GrainListItem::GrainListItem(QListView * parent, QString a, QString b,
-                             QString c, QString d, QString e, QString f,
-                             QString g, QString h )
-    : QListViewItem(parent, a, b, c, d, e, f, g, h), git_(0) { ; }
+GrainItem::GrainItem(QListView * parent) : QListViewItem(parent), git_(0) { ; }
 
-GrainListItem::~GrainListItem() {}
+GrainItem::~GrainItem() { ; }
 
-void GrainListItem::setToIterator()
+void GrainItem::refresh()
 {
-    setText(0, (*git_).name());
-    setText(1, QString::number((*git_).weight().amount(Weight::pound), 'f', 2));
-    setText(2, QString::number((*git_).extract(), 'f', 3));
-    setText(3, QString::number((*git_).color(), 'f', 1)
+    setText(GITEM_NAME, (*git_).name());
+    setText(GITEM_QUANTITY,
+            QString::number((*git_).weight().amount(Weight::pound), 'f', 2)
+            + " " + (*git_).weight().unit().symbol());
+    setText(GITEM_EXTRACT, QString::number((*git_).extract(), 'f', 3));
+    setText(GITEM_COLOR, QString::number((*git_).color(), 'f', 1)
             + AppResource::CHAR_LATIN_DEGREE);
-    setText(4, (*git_).useString());
+    setText(GITEM_USE, (*git_).useString());
 }
 
 // reimplemented for numerical sorting
-int GrainListItem::compare(QListViewItem* item, int column, bool asc) const
+int GrainItem::compare(QListViewItem* item, int column, bool asc) const
 {
     switch (column) {
-      case 1:
-      case 2:
-      case 3: { // remove suffixes and decimals in these fields
+      case GITEM_QUANTITY:
+      case GITEM_EXTRACT:
+      case GITEM_COLOR: { // remove suffixes and decimals in these fields
           QRegExp regex("[0-9.]+");
           regex.search(text(column));
           int first = (int) regex.cap(0).toDouble() * 1000;
