@@ -3,7 +3,7 @@
   -------------------
   A grain class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -34,12 +34,20 @@
 #define GRAIN_H
 
 #include <qlistview.h>
-#include <qstring.h>
+#include <qstringlist.h>
 #include <qvaluelist.h>
 
 #include "quantity.h"
 
-enum { GRAIN_OTHER, GRAIN_MASHED, GRAIN_STEEPED, GRAIN_EXTRACT };
+enum {
+    GRAIN_OTHER,
+    GRAIN_MASHED,
+    GRAIN_STEEPED,
+    GRAIN_EXTRACT
+};
+
+//////////////////////////////////////////////////////////////////////////////
+// Grain
 
 class Grain {
 public:
@@ -64,22 +72,22 @@ public:
     Weight &weight();
     void setWeight(const Weight &weight);
     // get/set extract
-    double extract();
+    double extract() const;
     void setExtract(double extract);
     // get/set color
-    double color();
+    double color() const;
     void setColor(double color);
     // get/set usage
-    int use();
+    int use() const;
     void setUse(int use);
 
     // return the yield (quantity times extract)
-    double yield();
+    double yield() const;
     // return the HCU (quantity times color)
-    double HCU();
+    double HCU() const;
         
     // return use as string
-    QString useString();
+    QString useString() const;
 
     // return a list of use strings
     static QStringList useStringList();
@@ -96,34 +104,9 @@ private:
     double hcu_;    // color yield for grain
 };
 
-// TODO map will be more efficient
 typedef QValueList<Grain> GrainList;
 typedef QValueList<Grain>::Iterator GrainIterator;
 
-// TODO: remove this from model
-class GrainListItem : public QListViewItem {
-public:
-    // constructor
-    GrainListItem(QListView * parent, QString, QString = QString::null,
-                  QString = QString::null, QString = QString::null,
-                  QString = QString::null, QString = QString::null,
-                  QString = QString::null, QString = QString::null );
-    // destructor
-    ~GrainListItem();
-    // get iterator to Grain item
-    GrainIterator grainIterator();
-    // set iterator to Grain item
-    void setGrainIterator(GrainIterator &it);
-    // set grain to match iterator
-    void setToIterator();
-
-    // custom sorting (to get numerical sort order)
-    int compare(QListViewItem* item, int col, bool asc) const;
-
-private:
-    GrainIterator git_;
-};
-
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
@@ -133,26 +116,62 @@ inline QString Grain::name() const { return name_; }
 
 inline void Grain::setWeight(const Weight &weight) { weight_ = weight; }
 
-inline Weight& Grain::weight() { return weight_; }
+inline Weight &Grain::weight() { return weight_; }
 
 inline void Grain::setExtract(double extract) { extract_ = extract; }
 
-inline double Grain::extract() { return extract_; }
+inline double Grain::extract() const { return extract_; }
 
 inline void Grain::setColor(double color) { color_ = color; }
 
-inline double Grain::color() { return color_; }
+inline double Grain::color() const { return color_; }
 
 inline void Grain::setUse(int use) { use_ = use; }
 
-inline int Grain::use() { return use_; }
+inline int Grain::use() const { return use_; }
 
-inline double Grain::yield() { return yield_; }
+inline double Grain::yield() const { return yield_; }
 
-inline double Grain::HCU() { return hcu_; }
+inline double Grain::HCU() const { return hcu_; }
 
-inline GrainIterator GrainListItem::grainIterator() { return git_; }
+//////////////////////////////////////////////////////////////////////////////
+// GrainItem
 
-inline void GrainListItem::setGrainIterator(GrainIterator &it) { git_ = it; }
+enum {
+    GITEM_NAME = 0,
+    GITEM_QUANTITY,
+    GITEM_EXTRACT,
+    GITEM_COLOR,
+    GITEM_USE
+};
+
+class GrainItem : public QListViewItem {
+public:
+    // constructor
+    GrainItem(QListView * parent);
+    // destructor
+    ~GrainItem();
+
+    // get the iterator
+    GrainIterator iterator();
+    // set the iterator
+    void setIterator(GrainIterator &it);
+
+    // refresh text from iterator
+    void refresh();
+
+    // custom sorting (to get numerical sort order)
+    int compare(QListViewItem* item, int col, bool asc) const;
+
+private:
+    GrainIterator git_; // iterator to grain in database
+};
+
+//////////////////////////////////////////////////////////////////////////////
+// Inlined Methods
+
+inline GrainIterator GrainItem::iterator() { return git_; }
+
+inline void GrainItem::setIterator(GrainIterator &it) { git_ = it; }
 
 #endif // GRAIN_H
