@@ -3,7 +3,7 @@
   -------------------
   A dialog page for grains
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -33,52 +33,41 @@
 #ifndef GRAINPAGE_H
 #define GRAINPAGE_H
 
+#include "grainview.h"
 #include "grain.h"
-#include "ingredientpage.h"
 
 class Model;
-class QCheckBox;
-class View;
 
-class GrainPage : public IngredientPage  {
+class GrainPage : public GrainView  {
     Q_OBJECT
 public:
     // constructor
-    GrainPage(Model *model, View *view, Controller *controller,
-              const char *name);
+    GrainPage(QWidget *parent, const char *name, Model *model);
     // destructor
-    ~GrainPage();
+    virtual ~GrainPage();
 
-public slots:
-    // document has changed
-    void documentChanged();
+    // initialize list and fields
+    void refresh();
+
+signals:
+    // emits on modification
+    void modified();
 
 private slots:
     // add a grain
-    void addGrain();    
+    void addGrain();
     // remove a grain
-    void removeGrain();    
+    void removeGrain();
     // apply / change a grain
-    void applyGrain();    
-    // update the widgets in the entry area
-    void updateEntryItems(const QString &name);
+    void applyGrain();
+    // update the entry fields
+    void updateFields(const QString &name);
     // an ingredient was selected
     void itemSelected(QListViewItem *item);
 
 private:
-    // update the list view
-    void updateListView();
-    // set a combobox to item
-    void setComboItem(QComboBox *combo, const QString &text);
-    
-private:
-    QLabel* extractlabel_;
-    FixedSpinBox* extractspin_;
-    QLabel* colorlabel_;
-    FixedSpinBox* colorspin_;
-    QLabel* uselabel_;
-    QComboBox* usecombo_;
-    GrainListItem* currentitem_;
+    Model *model_;
+    GrainItem* currentitem_;
 };
 
 #endif // GRAINPAGE_H
