@@ -3,7 +3,7 @@
   -------------------
   General purpose help file viewer
   -------------------
-  Copyright (c) 1999-2004 David Johnson
+  Copyright (c) 1999-2005 David Johnson
   Please see the header file for copyright and license information.
 ***************************************************************************/
 
@@ -40,10 +40,9 @@ using namespace AppResource;
 // Constructor
 
 HelpWindow::HelpWindow(const QString& home, QWidget* parent, const char *name)
-    : QMainWindow(parent, name, WDestructiveClose),
-      browser_(0), backward_(0), forward_(0), home_(0), print_(0), close_(0)
+    : QMainWindow(parent, name, WDestructiveClose), browser_(0), printer_(0)
 {
-    setUsesBigPixmaps(ID_PREF_LARGE_ICONS_DEFAULT);
+    setUsesBigPixmaps(Controller::instance()->state().general.largeicons);
     QIconSet::setIconSize(QIconSet::Large, QSize(22, 22));
 
     browser_ = new QTextBrowser(this);
@@ -65,69 +64,69 @@ HelpWindow::HelpWindow(const QString& home, QWidget* parent, const char *name)
     int height = QApplication::desktop()->height() * 3 / 4;
     resize(width, height);
 
+    // setup menus and toolbar
+    QPopupMenu* filemenu = new QPopupMenu(this);
+    QPopupMenu* navmenu = new QPopupMenu(this);
+    menuBar()->insertItem("&File", filemenu);
+    menuBar()->insertItem("&Navigate", navmenu);
+    QToolBar* toolbar = new QToolBar(this);
+
     // setup actions
-    print_ = new QAction("Print",
+    QAction *action;
+    action = new QAction("Back",
+                         QIconSet(Controller::findImage("sm_back"),
+                                  Controller::findImage("back")),
+                         "&Backward", ALT+Key_Left, this);
+    action->setStatusTip("Go to the previous page");
+    connect(action, SIGNAL(activated()), browser_, SLOT(backward()));
+    connect(browser_, SIGNAL(backwardAvailable(bool)),
+            action, SLOT(setEnabled(bool)));
+    action->setEnabled(false);
+    action->addTo(navmenu);
+    action->addTo(toolbar);
+
+    action = new QAction("Forward",
+                         QIconSet(Controller::findImage("sm_forward"),
+                                  Controller::findImage("forward")),
+                         "&Forward", ALT+Key_Right, this);
+    action->setStatusTip("Go to the next page");
+    connect(action, SIGNAL(activated()), browser_, SLOT(forward()));
+    connect(browser_, SIGNAL(forwardAvailable(bool)),
+            action, SLOT(setEnabled(bool)));
+    action->addTo(navmenu);
+    action->setEnabled(false);
+    action->addTo(toolbar);
+
+    action = new QAction("Home",
+                         QIconSet(Controller::findImage("sm_gohome"),
+                                  Controller::findImage("gohome")),
+                         "&Home", CTRL+Key_Home, this);
+    action->setStatusTip("Go to the index page");
+    connect(action, SIGNAL(activated()), browser_, SLOT(home()));
+    action->addTo(navmenu);
+    action->addTo(toolbar);
+
+    action = new QAction("Print",
                          QIconSet(Controller::findImage("sm_fileprint"),
                                   Controller::findImage("fileprint")),
                          "&Print...", CTRL+Key_P, this);
-    close_ = new QAction("Close",
+    action->setStatusTip("Print the document");
+    connect(action, SIGNAL(activated()), this, SLOT(print()));
+    action->addTo(filemenu);
+    toolbar->addSeparator();
+    action->addTo(toolbar);
+
+    action = new QAction("Close",
                          QIconSet(Controller::findImage("sm_exit"),
                                   Controller::findImage("exit")),
                          "&Close", CTRL+Key_Q, this);
-    backward_ = new QAction("Back",
-                            QIconSet(Controller::findImage("sm_back"),
-                                     Controller::findImage("back")),
-                            "&Backward", ALT+Key_Left, this);
-    forward_ = new QAction("Forward",
-                           QIconSet(Controller::findImage("sm_forward"),
-                                    Controller::findImage("forward")),
-                           "&Forward", ALT+Key_Right, this);
-    home_ = new QAction("Home",
-                        QIconSet(Controller::findImage("sm_gohome"),
-                                 Controller::findImage("gohome")),
-                        "&Home", CTRL+Key_Home, this);
-
-    print_->setStatusTip("Print the document");
-    close_->setStatusTip("Close the help viewer");
-    backward_->setStatusTip("Go to the previous page");
-    forward_->setStatusTip("Go to the next page");
-    home_->setStatusTip("Go to the index page");
-
-    connect(print_, SIGNAL(activated()), this, SLOT(print()));
-    connect(close_, SIGNAL(activated()), this, SLOT(close()));
-    connect(backward_, SIGNAL(activated()), browser_, SLOT(backward()));
-    connect(forward_, SIGNAL(activated()), browser_, SLOT(forward()));
-    connect(home_, SIGNAL(activated()), browser_, SLOT(home()));
-
-    QPopupMenu* filemenu = new QPopupMenu(this);
-    print_->addTo(filemenu);
+    action->setStatusTip("Close the help viewer");
+    connect(action, SIGNAL(activated()), this, SLOT(close()));
     filemenu->insertSeparator();
-    close_->addTo(filemenu);
-
-    QPopupMenu* navmenu = new QPopupMenu(this);
-    backward_->addTo(navmenu);
-    forward_->addTo(navmenu);
-    home_->addTo(navmenu);
-
-    menuBar()->insertItem("&File", filemenu);
-    menuBar()->insertItem("&Navigate", navmenu);
-
-    QToolBar* toolbar = new QToolBar(this);
-    backward_->addTo(toolbar);
-    forward_->addTo(toolbar);
-    home_->addTo(toolbar);
-    toolbar->addSeparator();
-    print_->addTo(toolbar);
-    close_->addTo(toolbar);
-
-    backward_->setEnabled(false);
-    forward_->setEnabled(false);
+    action->addTo(filemenu);
+    action->addTo(toolbar);
 
     // setup connections
-    connect(browser_, SIGNAL(backwardAvailable(bool)),
-            backward_, SLOT(setEnabled(bool)));
-    connect(browser_, SIGNAL(forwardAvailable(bool)),
-            forward_, SLOT(setEnabled(bool)));
     connect(browser_, SIGNAL(textChanged()),
             this, SLOT(textChanged()));
     connect(browser_, SIGNAL(highlighted(const QString&)), statusBar(),
@@ -141,7 +140,11 @@ HelpWindow::HelpWindow(const QString& home, QWidget* parent, const char *name)
 // -------------
 // Destructor
 
-HelpWindow::~HelpWindow() { ; }
+HelpWindow::~HelpWindow()
+{
+    if (browser_) delete browser_;
+    if (printer_) delete printer_;
+}
 
 //////////////////////////////////////////////////////////////////////////////
 // textChanged()
@@ -163,36 +166,43 @@ void HelpWindow::textChanged()
 
 void HelpWindow::print()
 {
-    QPrinter printer;
-    printer.setFullPage(true);
-    if (printer.setup()) {
-        QPainter p(&printer);
-        QPaintDeviceMetrics metrics(p.device());
+    if (!printer_) printer_ = new QPrinter(QPrinter::HighResolution);
+    printer_->setFullPage(true);
+    if (printer_->setup(this)) {
+        QPainter painter(printer_);
+	if (!painter.isActive()) return;
+        QPaintDeviceMetrics metrics(painter.device());
+
         int dpix = metrics.logicalDpiX();
         int dpiy = metrics.logicalDpiY();
-        const int margin = 72; // pt
-        QRect body(margin * dpix / 72, margin * dpiy / 72,
-            metrics.width() - margin * dpix / 72 * 2,
-            metrics.height() - margin * dpiy / 72 * 2);
-        QFont font("times", 10);
-        QSimpleRichText richText(browser_->text(), font, browser_->context(),
+        const int marginx = (int) (dpix * 2 / 2.54); // two cm margins
+        const int marginy = (int) (dpiy * 2 / 2.54); 
+
+        QFont font("sans", 10);
+	QRect body(marginx, marginy,
+                   metrics.width() - (2 * marginx),
+                   metrics.height() - (2 * marginx));
+	QSimpleRichText richtext(browser_->text(),
+                                 font,
+                                 browser_->context(),
                                  browser_->styleSheet(),
-                                 browser_->mimeSourceFactory(), body.height());
-        richText.setWidth(&p, body.width());
-        QRect view(body);
-        int page = 1;
-        while (true) {
-            richText.draw(&p, body.left(), body.top(), view, colorGroup());
-            view.moveBy(0, body.height());
-            p.translate(0, -body.height());
-            p.setFont(font);
-            p.drawText(view.right() -
-                       p.fontMetrics().width(QString::number(page)),
-                       view.bottom() + p.fontMetrics().ascent() + 5,
-                       QString::number(page));
-            if (view.top() >= richText.height()) break;
-            printer.newPage();
-            ++page;
-        }
+				 browser_->mimeSourceFactory(),
+                                 body.height());
+	richtext.setWidth(&painter, body.width() );
+
+	int page = 1;
+	while (true) {
+	    richtext.draw(&painter, marginx, marginy, body, colorGroup());
+	    body.moveBy(0, body.height());
+	    painter.translate(0, -body.height());
+	    painter.drawText(body.right()
+                             - painter.fontMetrics().width(QString::number(page)),
+                             body.bottom() + painter.fontMetrics().ascent() + 5, 
+                             QString::number(page));
+	    if (body.top()-marginy >= richtext.height())
+		break;
+	    printer_->newPage();
+	    page++;
+	}
     }
 }
