@@ -3,7 +3,7 @@
   -------------------
   General purpose help file viewer
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@
 
 #include <qmainwindow.h>
 
-class QAction;
+class QPrinter;
 class QTextBrowser;
 
 class HelpWindow : public QMainWindow
@@ -55,11 +55,7 @@ private slots:
 
 private:
     QTextBrowser* browser_;
-    QAction* backward_;
-    QAction* forward_;
-    QAction* home_;
-    QAction* print_;
-    QAction* close_;
+    QPrinter* printer_;
 };
 
 #endif // HELPWINDOW_H
