@@ -1,62 +1,56 @@
 /***************************************************************************
-  hops.cpp
+  hop.cpp
   -------------------
-  A hops class
+  A hop class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include <cmath>
-
 #include <qregexp.h>
 #include <qstringlist.h>
 
 #include "hops.h"
 
 //////////////////////////////////////////////////////////////////////////////
-// Construction, Destruction                                                //
+// Hop                                                                     //
 //////////////////////////////////////////////////////////////////////////////
 
 //////////////////////////////////////////////////////////////////////////////
-// Hops()
+// Hop()
 // ------
 // constructor
 
-Hops::Hops()
+Hop::Hop()
     : name_("Generic"), weight_(), form_( QString::null), alpha_(0.0), time_(0)
 { ; }
 
-Hops::Hops(const QString &name, const Weight &weight, const QString &form,
-           const double &alpha, const unsigned &time)
+Hop::Hop(const QString &name, const Weight &weight, const QString &form,
+         const double &alpha, const unsigned &time)
     : name_(name), weight_(weight), form_(form), alpha_(alpha), time_(time)
       
 {
     hbu_ = 0.75 * alpha * weight_.amount(Weight::ounce);
 }
 
-Hops::~Hops() { ; }
+Hop::~Hop() { ; }
 
 //////////////////////////////////////////////////////////////////////////////
-// Hops(const Hops &)
-// ------------------
+// Hop(const Hop &)
+// ----------------
 // Copy constructor
 
-Hops::Hops(const Hops &h)
+Hop::Hop(const Hop &h)
     : name_(h.name_), weight_(h.weight_), form_(h.form_), alpha_(h.alpha_),
       time_(h.time_), hbu_(h.hbu_)
 { ; }
 
-//////////////////////////////////////////////////////////////////////////////
-// Operators                                                                //
-//////////////////////////////////////////////////////////////////////////////
-
 //////////////////////////////////////////////////////////////////////////////
 // operator=()
 // -----------
 // Assignment operator
 
-Hops Hops::operator=(const Hops &h)
+Hop Hop::operator=(const Hop &h)
 {
     if (this != &h) {
         name_ = h.name_;
@@ -74,7 +68,7 @@ Hops Hops::operator=(const Hops &h)
 // ------------
 // Equivalence operator
 
-bool Hops::operator==(const Hops &h)
+bool Hop::operator==(const Hop &h)
 {
     return (name_ == h.name_)
         && (weight_ == h.weight_)
@@ -84,28 +78,30 @@ bool Hops::operator==(const Hops &h)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// HopsListItem Class                                                       //
+// HopItem Class                                                            //
 //////////////////////////////////////////////////////////////////////////////
 
-HopsListItem::HopsListItem(QListView * parent, QString a, QString b, QString c,
-                           QString d, QString e, QString f, QString g, QString h)
-    : QListViewItem(parent, a, b, c, d, e, f, g, h), hit_(0) { ; }
+HopItem::HopItem(QListView * parent) : QListViewItem(parent), hit_(0) { ; }
 
-void HopsListItem::setToIterator()
+HopItem::~HopItem() { ; }
+
+void HopItem::refresh()
 {
-    setText(0, (*hit_).name());
-    setText(1, QString::number((*hit_).weight().amount(), 'f', 2));
-    setText(2, (*hit_).form());
-    setText(3, QString::number((*hit_).alpha(), 'f', 1) + '%');
-    setText(4, QString::number((*hit_).time()));
+    setText(HITEM_NAME, (*hit_).name());
+    setText(HITEM_QUANTITY,
+            QString::number((*hit_).weight().amount(), 'f', 2)
+            + " " + (*hit_).weight().unit().symbol());
+    setText(HITEM_ALPHA, QString::number((*hit_).alpha(), 'f', 1) + '%');
+    setText(HITEM_FORM, (*hit_).form());
+    setText(HITEM_TIME, QString::number((*hit_).time()));
 }
 
 // reimplemented for numerical sorting
-int HopsListItem::compare(QListViewItem* item, int column, bool asc) const
+int HopItem::compare(QListViewItem* item, int column, bool asc) const
 {
     switch (column) {
-      case 1:
-      case 3: { // remove suffixes and decimals in these fields
+      case HITEM_QUANTITY:
+      case HITEM_ALPHA: { // remove suffixes and decimals in these fields
           QRegExp regex("[0-9.]+");
           regex.search(text(column));
           int first = (int) regex.cap(0).toDouble() * 1000;
@@ -114,7 +110,7 @@ int HopsListItem::compare(QListViewItem* item, int column, bool asc) const
           return (first - second);
       }
 
-      case 4: // plain int with no suffix
+      case HITEM_TIME: // plain int with no suffix
           return (text(column).toInt() - item->text(column).toInt());
 
       default:
