@@ -1,9 +1,9 @@
 /***************************************************************************
-  hops.h
+  hop.h
   -------------------
-  A hops class
+  A hop class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -30,8 +30,8 @@
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  ***************************************************************************/
 
-#ifndef HOPS_H
-#define HOPS_H
+#ifndef HOP_H
+#define HOP_H
 
 #include <qlistview.h>
 #include <qstring.h>
@@ -39,22 +39,25 @@
 
 #include "quantity.h"
 
-class Hops {
+//////////////////////////////////////////////////////////////////////////////
+// Hop
+
+class Hop {
 public:
     // default constructor
-    Hops();
+    Hop();
     // full constructor
-    Hops(const QString &nam, const Weight &weight,
-         const QString &form, const double &alpha,
-         const unsigned &time);
+    Hop(const QString &nam, const Weight &weight,
+        const QString &form, const double &alpha,
+        const unsigned &time);
     // copy constructor
-    Hops(const Hops &h);
+    Hop(const Hop &h);
     // assignment operator
-    Hops operator=(const Hops &h);
+    Hop operator=(const Hop &h);
     // comparison operator
-    bool operator==(const Hops &h);
+    bool operator==(const Hop &h);
     // destructor
-    ~Hops();
+    ~Hop();
 
     // get/set name
     QString name() const;
@@ -84,63 +87,71 @@ private:
     double hbu_;
 };
 
-// TODO: more efficient to use a map
-typedef QValueList<Hops> HopsList;
-typedef QValueList<Hops>::Iterator HopIterator;
+typedef QValueList<Hop> HopList;
+typedef QValueList<Hop>::Iterator HopIterator;
 
-// TODO: remove this from the model
-class HopsListItem : public QListViewItem {
+//////////////////////////////////////////////////////////////////////////////
+// Inlined Operators
+
+inline void Hop::setName(const QString &name) { name_ = name; }
+
+inline QString Hop::name() const { return name_; }
+
+inline void Hop::setWeight(const Weight &weight) { weight_ = weight; }
+
+inline Weight &Hop::weight() { return weight_; }
+
+inline void Hop::setForm(const QString &form) { form_ = form; }
+
+inline QString Hop::form() { return form_; }
+
+inline void Hop::setAlpha(double alpha) { alpha_ = alpha; }
+
+inline double Hop::alpha() { return alpha_; }
+
+inline void Hop::setTime(unsigned time) { time_ = time; }
+
+inline unsigned Hop::time() { return time_; }
+
+inline double Hop::HBU() { return hbu_; }
+
+//////////////////////////////////////////////////////////////////////////////
+// HopItem
+
+enum {
+    HITEM_NAME = 0,
+    HITEM_QUANTITY,
+    HITEM_ALPHA,
+    HITEM_FORM,
+    HITEM_TIME
+};
+
+class HopItem : public QListViewItem {
 public:
     // constructor
-    HopsListItem(QListView * parent, QString, QString = QString::null,
-                 QString = QString::null, QString = QString::null,
-                 QString = QString::null, QString = QString::null,
-                 QString = QString::null, QString = QString::null );
+    HopItem(QListView * parent);
     // destructor
-    ~HopsListItem();
-    // get iterator to Hop item
-    HopIterator hopIterator();
-    // set iterator to Hop item
-    void setHopIterator(HopIterator &it);
-    // set hop to match iterator
-    void setToIterator();
+    ~HopItem();
+
+    // get the iterator
+    HopIterator iterator();
+    // set the iterator
+    void setIterator(HopIterator &it);
+    // refresh text from iterator
+    void refresh();
 
     // custom sorting (to get numerical sort order)
     int compare(QListViewItem* item, int col, bool asc) const;
 
 private:
-    HopIterator hit_;
+    HopIterator hit_; // iterator to hop in database
 };
 
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Operators
 
-inline void Hops::setName(const QString &name) { name_ = name; }
+inline HopIterator HopItem::iterator() { return hit_; }
 
-inline QString Hops::name() const { return name_; }
+inline void HopItem::setIterator(HopIterator &it) { hit_ = it; }
 
-inline void Hops::setWeight(const Weight &weight) { weight_ = weight; }
-
-inline Weight &Hops::weight() { return weight_; }
-
-inline void Hops::setForm(const QString &form) { form_ = form; }
-
-inline QString Hops::form() { return form_; }
-
-inline void Hops::setAlpha(double alpha) { alpha_ = alpha; }
-
-inline double Hops::alpha() { return alpha_; }
-
-inline void Hops::setTime(unsigned time) { time_ = time; }
-
-inline unsigned Hops::time() { return time_; }
-
-inline double Hops::HBU() { return hbu_; }
-
-inline HopsListItem::~HopsListItem() { ; }
-
-inline HopIterator HopsListItem::hopIterator() { return hit_; }
-
-inline void HopsListItem::setHopIterator(HopIterator &it) { hit_ = it; }
-
-#endif // HOPS_H
+#endif // HOP_H
