@@ -3,7 +3,7 @@
   -------------------
   A dialog page for hops
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -33,49 +33,41 @@
 #ifndef HOPSPAGE_H
 #define HOPSPAGE_H
 
+#include "hopview.h"
 #include "hops.h"
-#include "ingredientpage.h"
 
-class QSpinBox;
-class QCheckBox;
-class FixedSpinBox;
+class Model;
 
-class HopsPage : public IngredientPage  {
+class HopPage : public HopView {
    Q_OBJECT
 public: 
     // constructor
-    HopsPage(Model *model, View *view, Controller *controller,
-             const char *name);
+    HopPage(QWidget *parent, const char *name, Model *model);
     // destructor
-    ~HopsPage();
+    virtual ~HopPage();
 
-    // document has changed
-    void documentChanged();
+    // initialize list and fields
+    void refresh();
+
+signals:
+    // emits on modification
+    void modified();
 
 private slots:
     // add clicked
-    void addHops();    
+    void addHop();    
     // remove clicked
-    void removeHops();    
+    void removeHop();    
     // apply clicked
-    void applyHops();    
-    // update the widgets in the entry area
-    void updateEntryItems(const QString &name);
+    void applyHop();    
+    // update entry fields
+    void updateFields(const QString &name);
     // an ingredient was selected
     void itemSelected(QListViewItem *item);
 
 private:
-    // update the list view
-    void updateListView();
-    
-private:
-    QLabel* formlabel_;
-    QComboBox* formcombo_;
-    QLabel* alphalabel_;
-    FixedSpinBox* alphaspin_;
-    QLabel* timelabel_;
-    QSpinBox* timespin_;
-    HopsListItem* currentitem_;
+    Model *model_;
+    HopItem* currentitem_;
 };
 
 #endif // HOPSPAGE_H
