@@ -3,19 +3,17 @@
   -------------------
   A miscellaneous ingredient class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-#include <cmath>
-
 #include <qregexp.h>
 #include <qstringlist.h>
 
 #include "miscingredient.h"
 
 //////////////////////////////////////////////////////////////////////////////
-// Construction, Destruction                                                //
+// MiscIngredient                                                           //
 //////////////////////////////////////////////////////////////////////////////
 
 //////////////////////////////////////////////////////////////////////////////
@@ -44,8 +42,9 @@ MiscIngredient::MiscIngredient(const MiscIngredient &m)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
-// Operators                                                                //
-//////////////////////////////////////////////////////////////////////////////
+// operator=()
+// -----------
+// Assignment operator
 
 MiscIngredient MiscIngredient::operator=(const MiscIngredient &m)
 {
@@ -57,6 +56,11 @@ MiscIngredient MiscIngredient::operator=(const MiscIngredient &m)
     return *this;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// operator==()
+// -----------
+// Equivalence operator
+
 bool MiscIngredient::operator==(const MiscIngredient &m)
 {
     return (name_ == m.name_)
@@ -65,30 +69,27 @@ bool MiscIngredient::operator==(const MiscIngredient &m)
 }
 
 //////////////////////////////////////////////////////////////////////////////
-// MiscIngredientListItem Class                                             //
+// MiscItem Class                                                           //
 //////////////////////////////////////////////////////////////////////////////
 
-MiscIngredientListItem::MiscIngredientListItem(QListView * parent,
-                                               QString a, QString b, QString c,
-                                               QString d, QString e, QString f,
-                                               QString g, QString h)
-    : QListViewItem(parent, a, b, c, d, e, f, g, h), mit_(0) { ; }
+MiscItem::MiscItem(QListView * parent) : QListViewItem(parent), mit_(0) { ; }
 
-MiscIngredientListItem::~MiscIngredientListItem() { ; }
+MiscItem::~MiscItem() { ; }
 
-void MiscIngredientListItem::setToIterator()
+void MiscItem::refresh()
 {
-    setText(0, (*mit_).name());
-    setText(1, QString::number((*mit_).quantity().amount(), 'f', 2));
-    setText(2, (*mit_).notes());
+    setText(MITEM_NAME, (*mit_).name());
+    setText(MITEM_QUANTITY,
+            QString::number((*mit_).quantity().amount(), 'f', 2)
+            + " " + (*mit_).quantity().unit().symbol());
+    setText(MITEM_NOTES, (*mit_).notes());
 }
 
 // reimplemented for numerical sorting
-int MiscIngredientListItem::compare(QListViewItem* item,
-                                    int column, bool asc) const
+int MiscItem::compare(QListViewItem* item, int column, bool asc) const
 {
     switch (column) {
-      case 1: { // remove suffixes and decimals in these fields
+      case MITEM_QUANTITY: { // remove suffixes and decimals in these fields
           QRegExp regex("[0-9.]+");
           regex.search(text(column));
           int first = (int) regex.cap(0).toDouble() * 1000;
