@@ -3,7 +3,7 @@
   -------------------
   A miscellaneous ingredient class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -38,6 +38,9 @@
 
 #include "quantity.h"
 
+//////////////////////////////////////////////////////////////////////////////
+// MiscIngredient
+
 class MiscIngredient {
 public:
     // default constructor
@@ -73,29 +76,6 @@ private:
 typedef QValueList<MiscIngredient> MiscIngredientList;
 typedef QValueList<MiscIngredient>::Iterator MiscIngredientIterator;
 
-// TODO: remove this from the model
-class MiscIngredientListItem : public QListViewItem {
-public:
-    // constructor
-    MiscIngredientListItem(QListView * parent, QString, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null, QString = QString::null,
-            QString = QString::null, QString = QString::null );
-    // destructor
-    ~MiscIngredientListItem();
-    // get iterator to misc item
-    MiscIngredientIterator miscIngredientIterator();
-    // set iterator to misc item
-    void setMiscIngredientIterator(MiscIngredientIterator &it);
-    // set misc to match iterator
-    void setToIterator();
-
-    // custom sorting (to get numerical sort order)
-    int compare(QListViewItem* item, int col, bool asc) const;
-
-private:
-    MiscIngredientIterator mit_;
-};
-
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
@@ -111,10 +91,43 @@ inline void MiscIngredient::setNotes(const QString &notes) { notes_ = notes; }
 
 inline QString MiscIngredient::notes() { return notes_; }
 
-inline MiscIngredientIterator MiscIngredientListItem::miscIngredientIterator()
+//////////////////////////////////////////////////////////////////////////////
+// MiscItem
+
+enum {
+    MITEM_NAME = 0,
+    MITEM_QUANTITY,
+    MITEM_NOTES
+};
+
+class MiscItem : public QListViewItem {
+ public:
+    // constructor
+    MiscItem(QListView * parent);
+    // destructor
+    ~MiscItem();
+
+    // get the iterator
+    MiscIngredientIterator iterator();
+    // set the iterator
+    void setIterator(MiscIngredientIterator &it);
+    // refresh text from iterator
+    void refresh();
+
+    // custom sorting (to get numerical sort order)
+    int compare(QListViewItem* item, int col, bool asc) const;
+
+private:
+    MiscIngredientIterator mit_; // iterator to ingredient in database
+};
+
+//////////////////////////////////////////////////////////////////////////////
+// Inlined Methods
+
+inline MiscIngredientIterator MiscItem::iterator()
     { return mit_; }
 
-inline void MiscIngredientListItem::setMiscIngredientIterator(MiscIngredientIterator &it)
+inline void MiscItem::setIterator(MiscIngredientIterator &it)
     { mit_ = it; }
 
 #endif // MISCINGREDIENT_H
