@@ -3,7 +3,7 @@
   -------------------
   A dialog page for miscellaneous ingredients
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -32,23 +32,25 @@
 #ifndef MISCPAGE_H
 #define MISCPAGE_H
 
+#include "miscview.h"
 #include "miscingredient.h"
-#include "ingredientpage.h"
 
-class QLineEdit;
+class Model;
 
-class MiscPage : public IngredientPage  {
+class MiscPage : public MiscView  {
    Q_OBJECT
 public:
     // constructor
-    MiscPage(Model *model, View *view, Controller *controller,
-             const char *name);
+    MiscPage(QWidget *parent, const char *name, Model *model);
     // destructor
-    ~MiscPage();
+    virtual ~MiscPage();
 
-public slots:
-    // document has changed
-    void documentChanged();
+    // initialize list and fields
+    void refresh();
+
+signals:
+    // emits on modification
+    void modified();
 
 private slots:
     // add clicked
@@ -57,19 +59,14 @@ private slots:
     void applyMiscIngredient();
     // remove clicked
     void removeMiscIngredient();
-    // update the widgets in the entry area
-    void updateEntryItems(const QString &name);
+    // update the entry fields
+    void updateFields(const QString &name);
     // an ingredient was selected
     void itemSelected(QListViewItem *item);
 
 private:
-    // update the list view
-    void updateListView();
-
-private:
-    QLabel* noteslabel_;
-    QLineEdit* notesedit_;
-    MiscIngredientListItem* currentitem_;
+    Model *model_;
+    MiscItem* currentitem_;
 };
 
 #endif // MISCPAGE_H
