@@ -3,7 +3,7 @@
   -------------------
   Model class for brewing
   -------------------
-  Copyright (c) 2001-2004 David Johnson
+  Copyright (c) 2001-2005 David Johnson
   Please see the header file for copyright and license information.
  ***************************************************************************/
 
@@ -23,13 +23,15 @@ using namespace CalcResource;
 
 Model *Model::instance_ = 0;
 
+// TODO: separate database related methods from recipe related methods?
+
 // Construction, Destruction /////////////////////////////////////////////////
 
 // Private constructor
 Model::Model()
     : QObject(0, "model"), defaultsize_(Volume(5.0, Volume::gallon)),
       defaultmash_(false), defaulthopform_(HOP_PELLET),
-      defaultgrainunit_(&Weight::pound), defaulthopsunit_(&Weight::ounce),
+      defaultgrainunit_(&Weight::pound), defaulthopunit_(&Weight::ounce),
       defaultmiscunit_(&Quantity::generic), graindb_(), hopdb_(), miscdb_(),
       styledb_(), recipe_(0), datadir_("")
 {
@@ -40,7 +42,7 @@ Model::Model()
             // else load in some defaults
             styledb_.append(Style());
             graindb_.append(Grain());
-            hopdb_.append(Hops());
+            hopdb_.append(Hop());
             miscdb_.append(MiscIngredient());
             UEntry u = {0, 20};
             Calc::addUEntry(u);
@@ -72,6 +74,15 @@ void Model::setDefaultSize(const Volume &v)
     recipe_->setSize(defaultsize_);
 }
 
+void Model::setDefaultStyle(const QString &s)
+{
+    StyleIterator it;
+    for (it=styledb_.begin(); it!=styledb_.end(); ++it) {
+        if (s == (*it).name()) defaultstyle_ = (*it);
+    }
+    recipe_->setStyle(defaultstyle_);
+}
+
 void Model::setDefaultStyle(const Style &s)
 {
     defaultstyle_ = s;
@@ -90,14 +101,14 @@ void Model::setDefaultGrainUnit(Unit &u)
         (*it).setWeight(Weight(1.0, u));    
 }
 
-void Model::setDefaultHopsUnit(Unit &u)
+void Model::setDefaultHopUnit(Unit &u)
 {
-    defaulthopsunit_ = &u;
+    defaulthopunit_ = &u;
     // convert recipe hop units
     HopIterator it;
     for (it = recipe_->hops()->begin(); it != recipe_->hops()->end(); ++it)
         (*it).weight().convert(u);
-    // convert hopsdb units
+    // convert hopdb units
     for (it = hopdb_.begin(); it != hopdb_.end(); ++it )
         (*it).setWeight(Weight(1.0, u));
 }
@@ -135,31 +146,105 @@ QStringList Model::stylesList()
 // -------
 // Return a style given its name
 
-Style &Model::style(const QString &name)
+Style *Model::style(const QString &name)
 {
-    static Style defaultstyle;
-
     StyleIterator it;
     for (it=styledb_.begin(); it!=styledb_.end(); ++it) {
-        if (name == (*it).name()) return (*it);
+        if (name == (*it).name()) return &(*it);
     }
-    return defaultstyle;
+    return 0;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// checkStyle()
+// ----------
+// Check existance of style
+
+bool Model::checkStyle(const QString &name)
+{
+    bool found = false;
+    StyleIterator it;
+    for (it=styledb_.begin(); it!=styledb_.end(); ++it) {
+        if (name == (*it).name()) found = true;
+    }
+    return found;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// addStyle()
+// ----------
+// Add style to database, replacing if replace parameter is set
+
+// TODO: need to use qmap for DB
+StyleIterator Model::addStyle(const Style &s, bool replace)
+{
+    bool found = false;
+    StyleIterator it;
+    for (it=styledb_.begin(); it!=styledb_.end(); ++it) {
+        if (s.name() == (*it).name()) {
+            found = true;
+            if (replace) styledb_.remove(it);
+        }
+    }
+
+    if (replace || !found) it = styledb_.append(s);
+    return it;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// removeStyle()
+// -------------
+// Remove a style from the database
+
+void Model::removeStyle(StyleIterator it)
+{
+    styledb_.remove(it);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 // checkGrain()
 // ----------
-// Check existance of ingredient, adding it to db if not found
+// Check existance of ingredient
 
-void Model::checkGrain(const Grain &g)
+bool Model::checkGrain(const QString &name)
 {
     bool found = false;
     GrainIterator it;
     for (it=graindb_.begin(); it!=graindb_.end(); ++it) {
-        if (g.name() == (*it).name()) found = true;
+        if (name == (*it).name()) found = true;
+    }
+    return found;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// addGrain()
+// ----------
+// Add grain to database, replacing if replace parameter is set
+
+// TODO: need to use qmap for DB. cant use it for recipe, but can use it here
+GrainIterator Model::addGrain(const Grain &g, bool replace)
+{
+    bool found = false;
+    GrainIterator it;
+    for (it=graindb_.begin(); it!=graindb_.end(); ++it) {
+        if (g.name() == (*it).name()) {
+            found = true;
+            if (replace) graindb_.remove(it);
+        }
     }
 
-    if (!found) graindb_.append(g);
+    if (replace || !found) it = graindb_.append(g);
+    return it;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// removeGrain()
+// -------------
+// Remove a grain from the database
+
+void Model::removeGrain(GrainIterator it)
+{
+    graindb_.remove(it);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -197,15 +282,45 @@ Grain* Model::grain(const QString &name)
 // ----------
 // Check existance of ingredient, adding it to db if not found
 
-void Model::checkHops(const Hops &h)
+bool Model::checkHop(const QString &h)
 {
     bool found = false;
     HopIterator it;
     for (it=hopdb_.begin(); it!=hopdb_.end(); ++it) {
-        if (h.name() == (*it).name()) found = true;
+        if (h == (*it).name()) found = true;
+    }
+    return found;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// addHop()
+// ----------
+// Add hop to database, replacing if replace parameter is set
+
+// TODO: need to use qmap for DB. cant use it for recipe, but can use it here
+HopIterator Model::addHop(const Hop &h, bool replace)
+{
+    bool found = false;
+    HopIterator it;
+    for (it=hopdb_.begin(); it!=hopdb_.end(); ++it) {
+        if (h.name() == (*it).name()) {
+            found = true;
+            if (replace) hopdb_.remove(it);
+        }
     }
 
-    if (!found) hopdb_.append(h);
+    if (replace || !found) it = hopdb_.append(h);
+    return it;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// removeHop()
+// -----------
+// Remove a hop from the database
+
+void Model::removeHop(HopIterator it)
+{
+    hopdb_.remove(it);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -248,7 +363,7 @@ QStringList Model::formsList()
 // -----
 // Return hop given its name
 
-Hops* Model::hop(const QString &name)
+Hop* Model::hop(const QString &name)
 {
     HopIterator it;
     for (it=hopdb_.begin(); it!=hopdb_.end(); ++it) {
@@ -262,15 +377,45 @@ Hops* Model::hop(const QString &name)
 // ----------
 // Check existance of ingredient, adding it to db if not found
 
-void Model::checkMisc(const MiscIngredient &m)
+bool Model::checkMisc(const QString &m)
 {
     bool found = false;
     MiscIngredientIterator it;
     for (it=miscdb_.begin(); it!=miscdb_.end(); ++it) {
-        if (m.name() == (*it).name()) found = true;
+        if (m == (*it).name()) found = true;
+    }
+    return found;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// addMisc()
+// ----------
+// Add ingredient to database, replacing if replace parameter is set
+
+// TODO: need to use qmap for DB. cant use it for recipe, but can use it here
+MiscIngredientIterator Model::addMisc(const MiscIngredient &m, bool replace)
+{
+    bool found = false;
+    MiscIngredientIterator it;
+    for (it=miscdb_.begin(); it!=miscdb_.end(); ++it) {
+        if (m.name() == (*it).name()) {
+            found = true;
+            if (replace) miscdb_.remove(it);
+        }
     }
 
-    if (!found) miscdb_.append(m);
+    if (replace || !found) it = miscdb_.append(m);
+    return it;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+// removeMisc()
+// ------------
+// Remove an ingredient from the database
+
+void Model::removeMisc(MiscIngredientIterator it)
+{
+    miscdb_.remove(it);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -364,10 +509,12 @@ bool Model::loadData(const QString &filename, bool quiet)
                     styledb_.append(Style(subelement.text(),
                         subelement.attribute(attrOGLow).toDouble(),
                         subelement.attribute(attrOGHigh).toDouble(),
-                        subelement.attribute(attrIBULow).toDouble(),
-                        subelement.attribute(attrIBUHigh).toDouble(),
-                        subelement.attribute(attrSRMLow).toDouble(),
-                        subelement.attribute(attrSRMHigh).toDouble()));
+                        subelement.attribute(attrFGLow, "0.0").toDouble(),
+                        subelement.attribute(attrFGHigh, "0.0").toDouble(),
+                        subelement.attribute(attrIBULow).toInt(),
+                        subelement.attribute(attrIBUHigh).toInt(),
+                        subelement.attribute(attrSRMLow).toInt(),
+                        subelement.attribute(attrSRMHigh).toInt()));
                 }
             }
         }
@@ -405,8 +552,8 @@ bool Model::loadData(const QString &filename, bool quiet)
             for (m=0; m<subnodes.count(); m++) {
                 if (subnodes.item(m).isElement()) {
                     subelement = subnodes.item(m).toElement();
-                    hopdb_.append(Hops(subelement.text(),
-                        Weight(1.0, *defaulthopsunit_), QString::null,
+                    hopdb_.append(Hop(subelement.text(),
+                        Weight(1.0, *defaulthopunit_), QString::null,
                         subelement.attribute(attrAlpha).toDouble(), 60));
                 }
             }
@@ -458,9 +605,10 @@ bool Model::loadData(const QString &filename, bool quiet)
 // ------------
 // Save info to data file
 
-void Model::saveData(const QString &filename)
+bool Model::saveData(const QString &filename)
 {
     QDomDocument doc(tagDoc);
+    doc.appendChild(doc.createProcessingInstruction("xml", "version=\"1.0\""));
 
     // create the root element
     QDomElement root = doc.createElement(doc.doctype().name());
@@ -477,6 +625,8 @@ void Model::saveData(const QString &filename)
         subelement.appendChild(doc.createTextNode((*sit).name()));
         subelement.setAttribute(attrOGLow, (*sit).OGLow());
         subelement.setAttribute(attrOGHigh, (*sit).OGHi());
+        subelement.setAttribute(attrFGLow, (*sit).FGLow());
+        subelement.setAttribute(attrFGHigh, (*sit).FGHi());
         subelement.setAttribute(attrIBULow, (*sit).IBULow());
         subelement.setAttribute(attrIBUHigh, (*sit).IBUHi());
         subelement.setAttribute(attrSRMLow, (*sit).SRMLow());
@@ -542,13 +692,16 @@ void Model::saveData(const QString &filename)
         // error opening file
         qWarning("Error: Cannot open file " + filename);
         datafile->close();
+        return false;
     }
 
     // write it out
     QTextStream textstream(datafile);
-    doc.save(textstream, 0);
+    doc.save(textstream, 2);
     datafile->close();
     delete (datafile);
+
+    return true;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -560,15 +713,49 @@ void Model::newRecipe()
 {
     if (recipe_) delete recipe_;
     recipe_ = new Recipe(QString::null, QString::null, defaultmash_,
-                         defaultsize_, defaultstyle_, GrainList(), HopsList(),
+                         defaultsize_, defaultstyle_, GrainList(), HopList(),
                          MiscIngredientList(), QString::null, QString::null);
     setModified(false);
     emit (recipeChanged());
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// nativeFormat()
+// -------------
+// Is the file in native QBrew format?
+// Defined as "recipe" doctype with "generator=qbrew"
+
+bool Model::nativeFormat(const QString &filename)
+{
+    QFile* datafile = new QFile(filename);
+    if (!datafile->open(IO_ReadOnly)) {
+        // error opening file
+        qWarning("Error: Cannot open " + filename);
+        datafile->close();
+        delete (datafile);
+        return false;
+    }
+
+    // parse document
+    QDomDocument doc;
+    bool status = doc.setContent(datafile);
+    datafile->close();
+    delete (datafile);
+    if (!status) return false;
+
+    // check the doctype
+    if (doc.doctype().name() != tagRecipe) return false;
+
+    // check generator
+    QDomElement root = doc.documentElement();
+    if (root.attribute(attrGenerator) != PACKAGE)  return false;
+
+    return true;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // loadRecipe()
-// ------
+// ------------
 // load the recipe from file
 
 bool Model::loadRecipe(const QString &filename)
@@ -644,7 +831,9 @@ bool Model::loadRecipe(const QString &filename)
     for (n=0; n<nodes.count(); ++n) {
         if (nodes.item(n).isElement()) {
             element = nodes.item(n).toElement();
-            recipe_->setStyle(style(element.text()));
+            // TODO: load/save entire style
+            Style *s = style(element.text());
+            recipe_->setStyle(s ? *s : defaultStyle());
         }
     }
     // get batch settings
@@ -652,14 +841,8 @@ bool Model::loadRecipe(const QString &filename)
     for (n=0; n<nodes.count(); ++n) {
         if (nodes.item(n).isElement()) {
             element = nodes.item(n).toElement();
-            if (element.hasAttribute(attrSize)) {
-                // backwards compatibility
-                recipe_->setSize(Volume(element.attribute(attrSize).toDouble(),
-                                        Volume::gallon));
-            } else {
-                recipe_->size().fromQString(element.attribute(attrQuantity),
-                                           Volume::gallon);
-            }
+            recipe_->setSize(Volume(element.attribute(attrQuantity),
+                                    Volume::gallon));
             recipe_->setMashed(element.attribute(attrMash).lower() == "true");
         }
     }
@@ -710,7 +893,7 @@ bool Model::loadRecipe(const QString &filename)
             for (m=0; m<subnodes.count(); m++) {
                 if (subnodes.item(m).isElement()) {
                     subelement = subnodes.item(m).toElement();
-                    recipe_->addHop(Hops(subelement.text(),
+                    recipe_->addHop(Hop(subelement.text(),
                         Weight(subelement.attribute(attrQuantity), Weight::ounce),
                         subelement.attribute(attrForm),
                         subelement.attribute(attrAlpha).toDouble(),
@@ -746,6 +929,17 @@ bool Model::loadRecipe(const QString &filename)
     return true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// importRecipe()
+// -------------
+// Import a recipe into the model
+
+bool Model::importRecipe(const QString &filename)
+{
+    qWarning("STUBBY: Model::importRecipe()");
+    return false;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 // saveRecipe()
 // ------------
@@ -754,6 +948,7 @@ bool Model::loadRecipe(const QString &filename)
 bool Model::saveRecipe(const QString &filename)
 {
     QDomDocument doc(tagRecipe);
+    doc.appendChild(doc.createProcessingInstruction("xml", "version=\"1.0\""));
 
     // create the root element
     QDomElement root = doc.createElement(doc.doctype().name());
@@ -770,6 +965,7 @@ bool Model::saveRecipe(const QString &filename)
     element.appendChild(doc.createTextNode(recipe_->brewer()));
     root.appendChild(element);
     // style
+    // TODO: load/save entire style
     element = doc.createElement(tagStyle);
     element.appendChild(doc.createTextNode(recipe_->style().name()));
     root.appendChild(element);
@@ -796,7 +992,7 @@ bool Model::saveRecipe(const QString &filename)
     element = doc.createElement(tagGrains);
     GrainIterator git;
     QDomElement subelement;
-    // iterate through _grains list
+    // iterate through grains list
     for (git=recipe_->grains()->begin(); git!=recipe_->grains()->end(); ++git) {
         subelement = doc.createElement(tagGrain);
         subelement.appendChild(doc.createTextNode((*git).name()));
@@ -811,7 +1007,7 @@ bool Model::saveRecipe(const QString &filename)
     // hops elements
     element = doc.createElement(tagHops);
     HopIterator hit;
-    // iterate through _hops list
+    // iterate through hops list
     for (hit=recipe_->hops()->begin(); hit!=recipe_->hops()->end(); ++hit) {
         subelement = doc.createElement(tagHop);
         subelement.appendChild(doc.createTextNode((*hit).name()));
@@ -826,7 +1022,7 @@ bool Model::saveRecipe(const QString &filename)
     // miscingredients elements
     element = doc.createElement(tagMiscIngredients);
     MiscIngredientIterator mit;
-    // iterate through _misc list
+    // iterate through misc list
     for (mit=recipe_->miscs()->begin(); mit!=recipe_->miscs()->end(); ++mit) {
         subelement = doc.createElement(tagMiscIngredient);
         subelement.appendChild(doc.createTextNode((*mit).name()));
@@ -847,7 +1043,7 @@ bool Model::saveRecipe(const QString &filename)
 
     // write it out
     QTextStream textstream(datafile);
-    doc.save(textstream, 0);
+    doc.save(textstream, 2);
     datafile->close();
     delete (datafile);
 
@@ -855,77 +1051,6 @@ bool Model::saveRecipe(const QString &filename)
     recipe_->setModified(false);
     return true;
 }
-
-//////////////////////////////////////////////////////////////////////////////
-// recipeText()
-// ------------
-// Get the ascii text of the recipe, for printing and exporting
-
-QString Model::recipeText()
-{
-    QString buffer = "\n";
-
-    // title stuff
-    buffer += "Recipe: " + recipe_->title() + '\n';
-    buffer += "Brewer: " + recipe_->brewer() + '\n';
-    buffer += "Style: " +
-        recipe_->style().name() + '\n';
-    buffer += "Batch: " + recipe_->size().toQString();
-    if (recipe_->mashed()) buffer += ", Mashed";
-    buffer += "\n\n";
-
-    // style stuff
-    buffer += "Recipe Gravity: " +
-        QString::number(Calc::OG(recipe_), 'f', 3) + " OG\n";
-    buffer += "Recipe Bitterness: " +
-        QString::number(Calc::IBU(recipe_), 'f', 0) + "IBU\n";
-    buffer += "Recipe Color: " +
-        QString::number(Calc::SRM(recipe_), 'f', 0) + CHAR_LATIN_DEGREE + "SRM\n";
-    buffer += "Estimated FG: " +
-        QString::number(Calc::FGEstimate(recipe_), 'f', 3) + '\n';
-    buffer += "Alcohol by Volume: " +
-        QString::number(Calc::ABV(recipe_) * 100.0, 'f', 1) + "%\n";
-    buffer += "Alcohol by Weight: " +
-        QString::number(Calc::ABW(recipe_) * 100.0, 'f', 1) + "%\n\n";
-
-    // grains
-    GrainList *grainlist = recipe_->grains();
-    GrainList::Iterator itg;
-    for (itg=grainlist->begin(); itg != grainlist->end(); ++itg) {
-        buffer += (*itg).name().leftJustify(30, ' ');
-        buffer += (*itg).weight().toQString() + ", ";
-        buffer += (*itg).useString() + '\n';
-    }
-    buffer += '\n';
-
-    // hops
-    HopsList *hopslist = recipe_->hops();
-    HopsList::Iterator ith;
-    for (ith=hopslist->begin(); ith != hopslist->end(); ++ith) {
-        buffer += (*ith).name().leftJustify(30, ' ');
-        buffer += (*ith).weight().toQString() + ", ";
-        buffer += (*ith).form() + ", ";
-        buffer += QString::number((*ith).time()) + " minutes\n";
-    }
-    buffer += '\n';
-
-    // misc ingredients
-    MiscIngredientList *misclist = recipe_->miscs();
-    MiscIngredientList::Iterator itm;
-    for (itm=misclist->begin(); itm != misclist->end(); ++itm) {
-        buffer += (*itm).name().leftJustify(30, ' ');
-        buffer += (*itm).quantity().toQString() + ", ";
-        buffer += (*itm).notes() + '\n';
-    }
-
-    // TODO: long notes don't wrap...
-    buffer += "Recipe Notes:\n" + recipe_->recipeNotes() + "\n\n";
-    buffer += "Batch Notes:\n" + recipe_->batchNotes() + "\n\n";
-
-    buffer += ID_TITLE + " " + VERSION;
-    return buffer;
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 // Miscellaneous                                                             //
 ///////////////////////////////////////////////////////////////////////////////
