@@ -3,7 +3,7 @@
   -------------------
   Model class for brewing
   -------------------
-  Copyright (c) 2001-2004 David Johnson
+  Copyright (c) 2001-2005 David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,8 @@
 #include "recipe.h"
 #include "style.h"
 
+class QDomElement;
+
 /**
  * A homebrewing domain model class. This is a singleton class, since there is
  * only one brewing domain model. Currently the model can only access one
@@ -56,56 +58,84 @@ class Model : public QObject {
 
     // Create a new recipe
     void newRecipe();
+    // Is the file a native format?
+    bool nativeFormat(const QString &filename);
     // Load a recipe into the model
     bool loadRecipe(const QString &filename);
+    // Import a recipe into the model
+    bool importRecipe(const QString &filename);
     // Save the current recipe
     bool saveRecipe(const QString &filename);
 
     // get/set the default size volume
     void setDefaultSize(const Volume &v);
-    const Volume &defaultSize();
+    const Volume &defaultSize() const;
     // get/set the default style
+    void setDefaultStyle(const QString &s);
     void setDefaultStyle(const Style &s);
-    const Style &defaultStyle();
+    const Style &defaultStyle() const;
     // get/set default mash
     void setDefaultMash(bool mash);
-    bool defaultMash();
+    bool defaultMash() const;
     // get/set default hop form
     void setDefaultHopform(const QString &form);
-    const QString &defaultHopform();
+    const QString &defaultHopform() const;
     // get/set the default grain units
     void setDefaultGrainUnit(Unit &u);
-    const Unit &defaultGrainUnit();
-    // get/set the default hops units
-    void setDefaultHopsUnit(Unit &u);
-    const Unit &defaultHopsUnit();
+    const Unit &defaultGrainUnit() const;
+    // get/set the default hop units
+    void setDefaultHopUnit(Unit &u);
+    const Unit &defaultHopUnit() const;
     // get/set the default misc units
     void setDefaultMiscUnit(Unit &u);
-    const Unit &defaultMiscUnit();
+    const Unit &defaultMiscUnit() const;
 
     // return a list of styles
     QStringList stylesList();
+    StyleList *styleDB();
     // return given style from name
-    Style &style(const QString &name);
+    Style *style(const QString &name);
+    // add style to database, replacing if asked
+    StyleIterator addStyle(const Style &s, bool replace);
+    // remove style from database
+    void removeStyle(StyleIterator it);
+    // check existance of style
+    bool checkStyle(const QString &s);
     // return a list of grains
     QStringList grainsList();
+    GrainList *grainDB();
     // return given grain from name
     Grain* grain(const QString &name);
+    // add grain to database, replacing if asked
+    GrainIterator addGrain(const Grain &g, bool replace);
+    // remove grain from database
+    void removeGrain(GrainIterator it);
+    // check existance of grain
+    bool checkGrain(const QString &g);
     // return a list of hops
     QStringList hopsList();
-    // return a list of hop styles (TODO: this should be in Hops class)
-    QStringList formsList();
+    HopList *hopDB();
     // return given hop from name
-    Hops* hop(const QString &name);
+    Hop* hop(const QString &name);
+    // add hop to database, replacing if asked
+    HopIterator addHop(const Hop &g, bool replace);
+    // remove hop from database
+    void removeHop(HopIterator it);
+    // check existance of hop
+    bool checkHop(const QString &h);
+    // return a list of hop forms (TODO: this should be in Hop class)
+    QStringList formsList();
     // return a list of misc ingredients
     QStringList miscList();
+    MiscIngredientList *miscDB();
     // return given misc ingredient from name
     MiscIngredient* misc(const QString &name);
-
-    // check validity of ingredients, adding them to db if not found
-    void checkGrain(const Grain &g);
-    void checkHops(const Hops &h);
-    void checkMisc(const MiscIngredient &m);
+    // add ingredient to database, replacing if asked
+    MiscIngredientIterator addMisc(const MiscIngredient &g, bool replace);
+    // remove ingredient from database
+    void removeMisc(MiscIngredientIterator it);
+    // check existance of ingredients
+    bool checkMisc(const QString &m);
 
     // return pointer to current recipe
     Recipe *recipe();
@@ -115,15 +145,29 @@ class Model : public QObject {
     // set modified status
     void setModified(bool mod);
 
-    // return the recipe as an ascii string
-    QString recipeText();
     // recalculate recipe
     void recalc();
 
     // set the data directory
     void setDataDir(const QString &datadir);
 
-signals:
+    // load the data
+    bool loadData(const QString &filename, bool quiet=false);
+    // save the data
+    bool saveData(const QString &filename);
+
+    // return the recipe as plain text
+    QString recipeText();
+    // export the recipe as plain text
+    bool exportText(const QString &filename);
+    // return the recipe as an html string
+    QString recipeHTML();
+    // export the recipe as html
+    bool exportHTML(const QString &filename);
+    // export the recipe in BeerXML format
+    bool exportBeerXML(const QString &filename);
+
+ signals:
     // a recipe has been loaded or created
     void recipeChanged();
     // send that the document has been modified
@@ -135,10 +179,9 @@ signals:
     // Private destructor
     ~Model();
 
-    // load the data
-    bool loadData(const QString &filename, bool quiet=false);
-    // save the data
-    void saveData(const QString &filename);
+    // load native file format
+    bool loadNativeRecipe(const QDomElement &root);
+
     // figure out the base directory for the data
     QString dataBase();
 
@@ -150,11 +193,11 @@ signals:
     bool defaultmash_;
     QString defaulthopform_;
     Unit *defaultgrainunit_;
-    Unit *defaulthopsunit_;
+    Unit *defaulthopunit_;
     Unit *defaultmiscunit_;
 
     GrainList graindb_;
-    HopsList hopdb_;
+    HopList hopdb_;
     MiscIngredientList miscdb_;
     StyleList styledb_;
 
@@ -169,19 +212,27 @@ inline void Model::setDefaultMash(bool mash) { defaultmash_ = mash; }
 
 inline void Model::setDefaultHopform(const QString &f) { defaulthopform_ = f; }
 
-inline const Volume &Model::defaultSize() { return defaultsize_; }
+inline const Volume &Model::defaultSize() const { return defaultsize_; }
 
-inline const Style &Model::defaultStyle() { return defaultstyle_; }
+inline const Style &Model::defaultStyle() const { return defaultstyle_; }
 
-inline bool Model::defaultMash() { return defaultmash_; }
+inline bool Model::defaultMash() const { return defaultmash_; }
 
-inline const QString &Model::defaultHopform() { return defaulthopform_; }
+inline const QString &Model::defaultHopform() const { return defaulthopform_; }
 
-inline const Unit &Model::defaultGrainUnit() { return *defaultgrainunit_; }
+inline const Unit &Model::defaultGrainUnit() const { return *defaultgrainunit_; }
 
-inline const Unit &Model::defaultHopsUnit() { return *defaulthopsunit_; }
+inline const Unit &Model::defaultHopUnit() const { return *defaulthopunit_; }
 
-inline const Unit &Model::defaultMiscUnit() { return *defaultmiscunit_; }
+inline const Unit &Model::defaultMiscUnit() const { return *defaultmiscunit_; }
+
+inline StyleList *Model::styleDB() { return &styledb_; }
+
+inline GrainList *Model::grainDB() { return &graindb_; }
+
+inline HopList *Model::hopDB() { return &hopdb_; }
+
+inline MiscIngredientList *Model::miscDB() { return &miscdb_; }
 
 inline Recipe *Model::recipe() { return recipe_; }
 
