@@ -3,7 +3,7 @@
   -------------------
   A dialog page for notes
   -------------------
-  Copyright 2003-2004, David Johnson
+  Copyright 2003-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -32,27 +32,24 @@
 #ifndef NOTEPAGE_H
 #define NOTEPAGE_H
 
-#include <qwidget.h>
-
-class QLabel;
-class QTextEdit;
+#include "noteview.h"
 
 class Model;
-class View;
-class Controller;
 
-class NotePage : public QWidget
-{
+class NotePage : public NoteView {
     Q_OBJECT
 public:
     // constructor
-    NotePage(Model *model, View *view, Controller *controller,
-             const char *name);
+    NotePage(QWidget *parent, const char *name, Model *model);
     // destructor
-    ~NotePage();
+    virtual ~NotePage();
 
-    // document has changed
-    void documentChanged();
+    // initialize
+    void refresh();
+
+signals:
+    // emits on modification
+    void modified();
 
 private slots:
     // recipe notes edited
@@ -62,11 +59,6 @@ private slots:
 
 private:
     Model *model_;
-    Controller *controller_;
-    QLabel* recipelabel_;
-    QTextEdit* recipeedit_;
-    QLabel* batchlabel_;
-    QTextEdit* batchedit_;
 };
 
 #endif // NOTEPAGE_H
