@@ -3,11 +3,11 @@
   -------------------
   Generic quantity class
   -------------------
-  Copyright 2001-2004, David Johnson
+  Copyright 2001-2005, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
-// version 0.1 (qt-ized)
+// version 0.1.1 (qt-ized)
 
 #include <qtextstream.h>
 
@@ -108,9 +108,9 @@ void Quantity::convert(const Unit &u)
 /**
  * Output quantity as a string, output is "xx.xx symbol".
  */
-QString Quantity::toQString()
+QString Quantity::toQString(int prec) const
 {
-    return (QString::number(amount_, 'f') + " " + unit_->symbol());
+    return (QString::number(amount_, 'f', prec) + " " + unit_->symbol());
 }
 
 /**
