@@ -3,7 +3,7 @@
   -------------------
   Generic quantity class
   -------------------
-  Copyright 2001-2004, David Johnson
+  Copyright 2001-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  ***************************************************************************/
 
-// version 0.1 (qt-ized)
+// version 0.1.1 (qt-ized)
 
 #ifndef QUANTITY_H
 #define QUANTITY_H
@@ -104,7 +104,7 @@ class Quantity {
     // Convert quantity to unit
     void convert(const Unit &u);
     // output quanitity as a string
-    QString toQString();
+    QString toQString(int prec=4) const;
     // set quantity from string
     void fromQString(const QString &from, const Unit &defaultunit = generic);
 
