@@ -3,7 +3,7 @@
   -------------------
   A brew recipe class.
   -------------------
-  Copyright 2001-2004, David Johnson
+  Copyright 2001-2005, David Johnson
   Please see the header file for copyright and license information
  ***************************************************************************/
 
@@ -21,7 +21,7 @@
 Recipe::Recipe()
     : title_(""), brewer_(""), mash_(false), size_(5.0, Volume::gallon),
       style_(),  grains_(), hops_(), miscs_(), recipenotes_(""), batchnotes_(""),
-      modified_(false), og_(0.0), ibu_(0.0), srm_(0.0)
+      modified_(false), og_(0.0), ibu_(0), srm_(0)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -30,11 +30,11 @@ Recipe::Recipe()
 // Full constructor
 Recipe::Recipe(const QString &title, const QString &brewer, bool mash,
                const Volume &size, const Style &style, const GrainList &grains,
-               const HopsList &hops, const MiscIngredientList &miscs,
+               const HopList &hops, const MiscIngredientList &miscs,
                const QString &recipenotes, const QString &batchnotes)
     : title_(title), brewer_(brewer), mash_(mash), size_(size), style_(style),
       grains_(grains), hops_(hops), miscs_(miscs), recipenotes_(recipenotes),
-      batchnotes_(batchnotes), modified_(false), og_(0.0), ibu_(0.0), srm_(0.0)
+      batchnotes_(batchnotes), modified_(false), og_(0.0), ibu_(0), srm_(0)
 { ; }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -45,7 +45,7 @@ Recipe::Recipe(const Recipe &r)
     : title_(r.title_), brewer_(r.brewer_), mash_(r.mash_), size_(r.size_),
       style_(r.style_), grains_(r.grains_), hops_(r.hops_), miscs_(r.miscs_),
       recipenotes_(r.recipenotes_), batchnotes_(r.batchnotes_), modified_(false),
-      og_(0.0), ibu_(0.0), srm_(0.0)
+      og_(0.0), ibu_(0), srm_(0)
 { ; }
 
 Recipe::~Recipe() { ; }
@@ -94,6 +94,7 @@ void Recipe::setSize(const Volume &s)
 
 GrainIterator Recipe::addGrain(const Grain &g)
 {
+    // TODO: need to keep list sorted
     GrainList::Iterator it;
     it = grains_.append(g);
     Calc::recalc(this);
@@ -130,9 +131,9 @@ void Recipe::removeGrain(GrainIterator it)
 // ----------
 // Add a hop ingredient to the recipe
 
-HopIterator Recipe::addHop(const Hops &h)
+HopIterator Recipe::addHop(const Hop &h)
 {
-    HopsList::Iterator it;
+    HopList::Iterator it;
     it = hops_.append(h);
     Calc::recalc(this);
     modified_ = true;
@@ -144,7 +145,7 @@ HopIterator Recipe::addHop(const Hops &h)
 // ------------
 // Apply (change) a hop ingredient to the recipe
 
-void Recipe::applyHop(HopIterator it, const Hops &h)
+void Recipe::applyHop(HopIterator it, const Hop &h)
 {
     (*it) = h;
     Calc::recalc(this);
@@ -201,3 +202,24 @@ void Recipe::removeMisc(MiscIngredientIterator it)
     modified_ = true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+// recipeType()
+// ------------
+// Return type of recipe
+
+int Recipe::recipeType()
+{
+    int extract = 0;
+    int mash = 0;
+    GrainIterator it;
+    for (it=grains_.begin(); it!=grains_.end(); ++it) {
+        if ((*it).use() == GRAIN_MASHED) mash++;
+        else if ((*it).use() == GRAIN_EXTRACT) extract++;
+    }
+
+    if (mash > 0) {
+        if (extract > 0) return TypePartial;
+        else             return TypeAllGrain;
+    }
+    return TypeExtract;
+}
