@@ -3,7 +3,7 @@
   -------------------
   A brew recipe class
   -------------------
-  Copyright 2001-2004, David Johnson
+  Copyright 2001-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -52,7 +52,7 @@ class Recipe {
     // full constructor
     Recipe(const QString &title, const QString &brewer, bool mash,
            const Volume &size, const Style &style, const GrainList &grains,
-           const HopsList &hops, const MiscIngredientList &miscs,
+           const HopList &hops, const MiscIngredientList &miscs,
            const QString &recipenotes, const QString &batchnotes);
     // copy constructor
     Recipe(const Recipe &r);
@@ -62,25 +62,25 @@ class Recipe {
     Recipe operator=(const Recipe &r);
 
     // get and set
-    QString& title();
+    const QString& title() const;
     void setTitle(const QString &t);
-    QString& brewer();
+    const QString& brewer() const;
     void setBrewer(const QString &b);
-    bool mashed();
+    bool mashed() const;
     void setMashed(bool m);
-    Volume &size();
+    const Volume &size() const;
     void setSize(const Volume &s);
-    Style &style();
+    const Style &style() const;
     void setStyle(const Style &s);
     GrainList *grains();
     void setGrains(const GrainList &gl);
-    HopsList *hops();
-    void setHops(const HopsList &hl);
+    HopList *hops();
+    void setHops(const HopList &hl);
     MiscIngredientList *miscs();
     void setMiscs(const MiscIngredientList &ml);
-    QString& recipeNotes();
+    const QString& recipeNotes() const;
     void setRecipeNotes(const QString &n);
-    QString& batchNotes();
+    const QString& batchNotes() const;
     void setBatchNotes(const QString &n);
 
     // has the data been modified?
@@ -95,9 +95,9 @@ class Recipe {
     // remove a grain from the recipe
     void removeGrain(GrainIterator it);
     // add a hop to the recipe
-    HopIterator addHop(const Hops &h);
+    HopIterator addHop(const Hop &h);
     // apply a hop to the recipe
-    void applyHop(HopIterator it, const Hops &h);
+    void applyHop(HopIterator it, const Hop &h);
     // remove a hop from the recipe
     void removeHop(HopIterator it);
     // add a misc ingredient to the recipe
@@ -107,6 +107,10 @@ class Recipe {
     // remove a misc ingredient from the recipe
     void removeMisc(MiscIngredientIterator it);
 
+    // return type of recipe
+    enum RecipeType { TypeExtract, TypePartial, TypeAllGrain };
+    int recipeType();
+
  private:
     QString title_;
     QString brewer_;
@@ -114,7 +118,7 @@ class Recipe {
     Volume size_;
     Style style_;
     GrainList grains_;
-    HopsList hops_;
+    HopList hops_;
     MiscIngredientList miscs_;
     QString recipenotes_;
     QString batchnotes_;
@@ -123,35 +127,35 @@ class Recipe {
 
     friend class Calc;
     double og_;
-    double ibu_;
-    double srm_;
+    int ibu_;
+    int srm_;
 
 };
 
 // Inlined Methods //////////////////////////////////////////////////////////
 
-inline QString &Recipe::title()
+inline const QString &Recipe::title() const
     { return title_; }
 
 inline void Recipe::setTitle(const QString &t)
     { title_ = t; modified_ = true; }
 
-inline QString &Recipe::brewer()
+inline const QString &Recipe::brewer() const
     { return brewer_; }
 
 inline void Recipe::setBrewer(const QString &b)
     { brewer_ = b;  modified_ = true; }
 
-inline bool Recipe::mashed()
+inline bool Recipe::mashed() const
     { return mash_; }
 
 inline void Recipe::setMashed(bool m)
     { mash_ = m;  modified_ = true; }
 
-inline Volume &Recipe::size()
+inline const Volume &Recipe::size() const
     { return size_; }
 
-inline Style &Recipe::style()
+inline const Style &Recipe::style() const
     { return style_; }
 
 inline void Recipe::setStyle(const Style &s)
@@ -163,10 +167,10 @@ inline GrainList *Recipe::grains()
 inline void Recipe::setGrains(const GrainList &gl)
     { grains_ = gl;  modified_ = true; }
 
-inline HopsList *Recipe::hops()
+inline HopList *Recipe::hops()
     { return &hops_; }
 
-inline void Recipe::setHops(const HopsList &hl)
+inline void Recipe::setHops(const HopList &hl)
     { hops_ = hl;  modified_ = true; }
 
 inline MiscIngredientList *Recipe::miscs()
@@ -175,13 +179,13 @@ inline MiscIngredientList *Recipe::miscs()
 inline void Recipe::setMiscs(const MiscIngredientList &ml)
     { miscs_ = ml;  modified_ = true; }
 
-inline QString& Recipe::recipeNotes()
+inline const QString& Recipe::recipeNotes() const
     { return recipenotes_; }
 
 inline void Recipe::setRecipeNotes(const QString &n)
     { recipenotes_ = n; modified_ = true; }
 
-inline QString& Recipe::batchNotes()
+inline const QString& Recipe::batchNotes() const
     { return batchnotes_; }
 
 inline void Recipe::setBatchNotes(const QString &n)
