@@ -3,7 +3,7 @@
   -------------------
   Global resources for QBrew. Constants, enumerations and strings.
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -41,7 +41,7 @@
 #else
 #define PACKAGE "qbrew"
 #define PREFIX "/usr/local"
-#define VERSION "0.3.4"
+#define VERSION "0.3.5"
 #define PACKAGE_BUGREPORT "<bugs@usermode.org>"
 #endif
 
@@ -81,7 +81,7 @@ const QString HOP_WHOLE             = "whole";
 
 const QString ID_TITLE              = "QBrew";
 const QString ID_DESCRIPTION        = "A Homebrewer's Recipe Calculator";
-const QString ID_COPYRIGHT          = "Copyright 1999-2004";
+const QString ID_COPYRIGHT          = "Copyright 1999-2005";
 const QString ID_AUTHOR             = "David Johnson";
 const QString ID_AUTHOR_EMAIL       = "david@usermode.org";
 const QString ID_CONTRIBUTORS       = "Rob Hudson, "
@@ -99,8 +99,19 @@ const QChar CHAR_NBSP               = QChar(0xA0);  // TODO: make portable
 // file locations and stuff
 
 const QString ID_FILE_EXT           = "qbrew";
-const QString ID_FILE_FILTER
-    = ID_TITLE + " files (*." + ID_FILE_EXT + ");;All files (*)";
+const QString ID_FILE_FILTER        = "QBrew recipes (*.qbrew)";
+const QString ID_TEXT_FILTER        = "Text files (*.txt)";
+const QString ID_HTML_FILTER        = "HTML files (*.html *htm)";
+const QString ID_BEERXML_FILTER     = "BeerXML recipes (*.xml)";
+const QString ID_ALL_FILTER         = "All files (*)";
+const QString ID_OPEN_FILTER        = ID_FILE_FILTER + ";;"
+                                      + ID_BEERXML_FILTER + ";;"
+                                      + ID_ALL_FILTER;
+const QString ID_SAVE_FILTER        = ID_FILE_FILTER + ";;" + ID_ALL_FILTER;
+const QString ID_EXPORT_FILTER      = ID_HTML_FILTER + ";;"
+                                      + ID_BEERXML_FILTER + ";;"
+                                      + ID_TEXT_FILTER;
+
 const QString ID_PREFERENCES_FILE   = ".qbrewrc";
 const QString ID_HELP_FILE          = "qbrew-handbook.html";
 const QString ID_PRIMER_FILE        = "primer.html";
@@ -158,7 +169,6 @@ const QString ID_PREF_EFFICIENCY        = "Efficiency";
 const double ID_PREF_EFFICIENCY_DEFAULT = 0.75;
 const QString ID_PREF_TINSETH           = "Tinseth";
 const bool ID_PREF_TINSETH_DEFAULT      = false;
-// TODO: get rid of default recipe style option
 const QString ID_PREF_RECIPE_STYLE      = "RecipeStyle";
 const QString ID_PREF_RECIPE_STYLE_DEFAULT  = "Generic Ale";
 const QString ID_PREF_UNITS             = "Units";
