@@ -3,7 +3,7 @@
   -------------------
   AHA-like style class
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -33,17 +33,22 @@
 #ifndef STYLE_H
 #define STYLE_H
 
+#include <qlistview.h>
 #include <qvaluelist.h>
 
 class QString;
 
+//////////////////////////////////////////////////////////////////////////////
+// Style
+
 class Style {
   public:
     // full constructor
-    Style(const QString name="Generic Ale", const double &oglow=0.0,
-          const double &oghi=1.0, const double &ibulow=0.0,
-          const double &ibuhi=100.0, const double &srmlow=0.0,
-          const double &srmhi=40.0);
+    Style(const QString name="Generic Ale",
+          const double &oglow=0.0, const double &oghi=0.0,
+          const double &fglow=0.0, const double &fghi=0.0,
+          const int &ibulow=0, const int &ibuhi=100,
+          const int &srmlow=0, const int &srmhi=40);
     // copy constructor
     Style(const Style &s);
     // assignment operator
@@ -54,28 +59,34 @@ class Style {
     ~Style();
 
     // return name of style
-    const QString &name();
+    const QString &name() const;
     // return high end of OG
-    double OGHi();
+    double OGHi() const;
     // return low end of OG
-    double OGLow();
+    double OGLow() const;
+    // return high end of FG
+    double FGHi() const;
+    // return low end of FG
+    double FGLow() const;
     // return high end of IBU
-    double IBUHi();
+    int IBUHi() const;
     // return low end of IBU
-    double IBULow();
+    int IBULow() const;
     // return high end of SRM
-    double SRMHi();
+    int SRMHi() const;
     // return low end of SRM
-    double SRMLow();
+    int SRMLow() const;
     
   private:
     QString name_;
     double oglow_;
     double oghi_;
-    double ibulow_;
-    double ibuhi_;
-    double srmlow_;
-    double srmhi_;
+    double fglow_;
+    double fghi_;
+    int ibulow_;
+    int ibuhi_;
+    int srmlow_;
+    int srmhi_;
 };
 
 typedef QValueList<Style> StyleList;
@@ -84,18 +95,66 @@ typedef QValueList<Style>::Iterator StyleIterator;
 //////////////////////////////////////////////////////////////////////////////
 // Inlined Methods
 
-inline const QString &Style::name() { return name_; }
+inline const QString &Style::name() const { return name_; }
 
-inline double Style::OGHi() { return oghi_; }
+inline double Style::OGHi() const { return oghi_; }
 
-inline double Style::OGLow() { return oglow_; }
+inline double Style::OGLow() const { return oglow_; }
 
-inline double Style::IBUHi() { return ibuhi_; }
+inline double Style::FGHi() const { return fghi_; }
 
-inline double Style::IBULow() { return ibulow_; }
+inline double Style::FGLow() const { return fglow_; }
 
-inline double Style::SRMHi() { return srmhi_; }
+inline int Style::IBUHi() const { return ibuhi_; }
 
-inline double Style::SRMLow() { return srmlow_; }
+inline int Style::IBULow() const { return ibulow_; }
+
+inline int Style::SRMHi() const { return srmhi_; }
+
+inline int Style::SRMLow() const { return srmlow_; }
+
+//////////////////////////////////////////////////////////////////////////////
+// StyleItem
+
+enum {
+    SITEM_NAME = 0,
+    SITEM_OGLOW,
+    SITEM_OGHI,
+    SITEM_FGLOW,
+    SITEM_FGHI,
+    SITEM_IBULOW,
+    SITEM_IBUHI,
+    SITEM_SRMLOW,
+    SITEM_SRMHI
+};
+
+class StyleItem : public QListViewItem {
+public:
+    // constructor
+    StyleItem(QListView * parent);
+    // destructor
+    ~StyleItem();
+
+    // get the iterator
+    StyleIterator iterator();
+    // set the iterator
+    void setIterator(StyleIterator &it);
+
+    // refresh text from iterator
+    void refresh();
+
+    // custom sorting (to get numerical sort order)
+    int compare(QListViewItem* item, int col, bool asc) const;
+
+private:
+    StyleIterator sit_; // iterator to style in database
+};
+
+//////////////////////////////////////////////////////////////////////////////
+// Inlined Methods
+
+inline StyleIterator StyleItem::iterator() { return sit_; }
+
+inline void StyleItem::setIterator(StyleIterator &it) { sit_ = it; }
 
 #endif // STYLE_H
