@@ -3,7 +3,7 @@
   -------------------
   View class for QBrew
   -------------------
-  Copyright 1999-2004, David Johnson
+  Copyright 1999-2005, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -33,28 +33,18 @@
 #ifndef VIEW_H
 #define VIEW_H
 
-#include <qwidget.h>
-
-class QBoxLayout;
-class QCheckBox;
-class QComboBox;
-class QFrame;
-class QGridLayout;
-class QGroupBox;
-class QLabel;
-class QLineEdit;
-class QTabWidget;
+#include "viewwidget.h"
 
 class FixedSpinBox;
 class GrainPage;
-class HopsPage;
+class HopPage;
 class MiscPage;
 class NotePage;
 
 class Controller;
 class Model;
 
-class View : public QWidget {
+class View : public ViewWidget {
     Q_OBJECT
  public:
     // constructor
@@ -66,8 +56,10 @@ class View : public QWidget {
     static void setComboItem(QComboBox *combo, const QString &txt);
 
  public slots:
-    // document has changed
-    void flushView();
+    // refresh the entire view
+    void flush();
+    // refresh just the characteristics
+    void refresh();
 
     // set the recipe title
     void setTitle(const QString &title);
@@ -80,51 +72,12 @@ class View : public QWidget {
     // set mashed / unmashed
     void setMash(bool mash);
 
- private:
-    // initialize layouts
-    void initLayouts();
-    // initialize widgets
-    void initWidgets();
-
-    // update the style box
-    void updateStyle();
-
 private:
     Controller *controller_;
     Model *model_;
 
-    QBoxLayout* mainlayout_;
-    QGridLayout* recipelayout_;
-    QGridLayout* stylelayout_;
-
-    QLabel* titlelabel_;
-    QLineEdit* titleedit_;
-    QLabel* stylelabel_;
-    QComboBox* stylecombo_;
-    QLabel* brewerlabel_;
-    QLineEdit* breweredit_;
-    QCheckBox* mashcheck_;
-    QLabel* sizelabel_;
-    FixedSpinBox* sizespin_;
-    
-    QGroupBox* stylebox_;
-    QLabel* ogminimum_;
-    QLabel* ogmaximum_;
-    QLabel* ogrecipe_;
-    QLabel* ibuminimum_;
-    QLabel* ibumaximum_;
-    QLabel* iburecipe_;
-    QLabel* srmminimum_;
-    QLabel* srmmaximum_;
-    QLabel* srmrecipe_;
-    QFrame* vertseparator_;
-    QLabel* finalgravity_;
-    QLabel* alcoholbyvol_;
-    QLabel* alcoholbywgt_;
-
-    QTabWidget* ingredienttab_;
     GrainPage* grainpage_;
-    HopsPage* hoppage_;
+    HopPage* hoppage_;
     MiscPage* miscpage_;
     NotePage* notepage_;
 };
